sequencetools.Tree
==================

.. inheritance-diagram:: abjad.tools.sequencetools.Tree.Tree.Tree
   :private-bases:

.. autoclass:: abjad.tools.sequencetools.Tree.Tree.Tree

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.children

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.depth

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.improper_parentage

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.index_in_parent

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.level

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.negative_level

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.position

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.proper_parentage

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.root

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.width

Methods
-------

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.get_next_n_complete_nodes_at_level

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.get_next_n_nodes_at_level

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.get_node_at_position

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.get_position_of_descendant

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.is_at_level

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.iterate_at_level

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.iterate_depth_first

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.iterate_payload

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.remove

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.remove_to_root

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.to_nested_lists

Special Methods
---------------

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__contains__

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__eq__

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__getitem__

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__len__

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__ne__

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__repr__

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__str__
